@@ -74,7 +74,6 @@ PyObject* meth_set_active_vnet_channel(PyObject* self, PyObject* args);
 PyObject* meth_override_library_name(PyObject* self, PyObject* args);
 PyObject* meth_get_library_path(PyObject* self);
 PyObject* meth_set_bit_rate(PyObject* self, PyObject* args);
-PyObject* meth_set_bit_rate(PyObject* self, PyObject* args);
 PyObject* meth_set_fd_bit_rate(PyObject* self, PyObject* args);
 PyObject* meth_set_bit_rate_ex(PyObject* self, PyObject* args);
 PyObject* meth_get_timestamp_for_msg(PyObject* self, PyObject* args);
@@ -1088,7 +1087,7 @@ PyObject* meth_enable_network_com(PyObject* self, PyObject* args); //icsneoEnabl
 #define _DOC_OVERRIDE_LIBRARY_NAME \
     MODULE_NAME ".override_library_name(new_name)\n" \
     "\n" \
-    "Sets active vnet channel for the device.\n" \
+    "Overrides the default search for loading the icsneo40 library\n" \
     "\n" \
     "Args:\n" \
     "\tname: Absolute path or relative path including filename.\n\n" \
@@ -1111,7 +1110,15 @@ PyObject* meth_enable_network_com(PyObject* self, PyObject* args); //icsneoEnabl
 #define _DOC_SET_BIT_RATE \
     MODULE_NAME ".set_bit_rate(device, BitRate, NetworkID)\n" \
     "\n" \
-    "Sets the bitrate for a given Network ID on the device..\n" \
+    "Specifies bit rate setting. Valid values depend on the network specified.\n" \
+    "\n" \
+    "For the networks NETID_HSCAN, NETID_MSCAN, NETID_SWCAN, NETID_FIRE_HSCAN2, NETID_HSCAN3, NETID_LSFTCAN,\n" \
+    "valid bit rates are 2000, 33333, 50000, 62500, 83333, 100000, 125000, 250000, 500000, 800000, 1000000\n" \
+    "\n" \
+    "For the networks NETID_LIN, NETID_ISO2, NETID_FIRE_LIN2, NETID_FIRE_LIN3, NETID_FIRE_LIN4,\n" \
+    "valid bit rates are\n" \
+    "\n" \
+    "For the network NETID_FIRE_CGI valid bit rates are 625000 and 115200\n" \
     "\n" \
     "Args:\n" \
     "\tdevice (:class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`): :class:`" MODULE_NAME "." NEO_DEVICE_OBJECT_NAME "`\n\n" \
@@ -1139,7 +1146,7 @@ PyObject* meth_enable_network_com(PyObject* self, PyObject* args); //icsneoEnabl
     "\n"
 
 #define _DOC_SET_BIT_RATE_EX \
-    MODULE_NAME ".set_fd_bit_rate_ex(device, BitRate, NetworkID, iOptions)\n" \
+    MODULE_NAME ".set_bit_rate_ex(device, BitRate, NetworkID, iOptions)\n" \
     "\n" \
     "Sets the bitrate for a given Network ID on the device with extended options.\n" \
     "\n" \
